@@ -4,7 +4,7 @@ use warnings;
 
 package Meerkat;
 # ABSTRACT: Manage MongoDB documents as Moose objects
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 # Dependencies
 use Moose 2;
@@ -19,8 +19,16 @@ use Types::Standard qw/:types/;
 
 use namespace::autoclean;
 
-with 'MooseX::Role::Logger', 'MooseX::Role::MongoDB' => { -version => 0.005 };
+with 'MooseX::Role::Logger', 'MooseX::Role::MongoDB' => { -version => 0.006 };
 
+# =attr model_namespace (required)
+#
+# A perl module namespace that will be prepended to class names requested
+# via the L</collection> method.  If C<model_namespace> is "My::Model", then
+# C<< $meerkat->collection("Baz") >> will load and associate the
+# C<My::Model::Baz> class in the returned collection object.
+#
+# =cut
 
 has model_namespace => (
     is       => 'ro',
@@ -28,6 +36,14 @@ has model_namespace => (
     required => 1,
 );
 
+# =attr database_name (required)
+#
+# A MongoDB database name used to store all collections generated via the Meerkat
+# object and its collection factories.  Unless a C<db_name> is provided in the
+# C<client_options> attribute, this database will be the default for
+# authentication.
+#
+# =cut
 
 has database_name => (
     is       => 'ro',
@@ -35,6 +51,16 @@ has database_name => (
     required => 1,
 );
 
+# =attr client_options
+#
+# A hash reference of L<MongoDB::MongoClient> options that will be passed to its
+# C<connect> method.
+#
+# Note: The C<dt_type> will be forced to C<undef> so that the MongoDB client will
+# provide time values as epoch seconds.  See the L<Meerkat::Cookbook> for more on
+# dealing with dates and times.
+#
+# =cut
 
 has client_options => (
     is      => 'ro',
@@ -42,6 +68,18 @@ has client_options => (
     default => sub { {} },
 );
 
+# =attr collection_namespace
+#
+# A perl module namespace that will be be used to search for custom collection
+# classes.  The C<collection_namespace> will be prepended to class names
+# requested via the L</collection> method.  If C<collection_namespace> is
+# "My::Collection", then C<< $meerkat->collection("Baz") >> will load and use
+# C<My::Collection::Baz> for constructing a collection object.  If
+# C<collection_namespace> is not provided or if no class is found under the
+# namespace (or if it fails to load), then collection objects will be constructed
+# using L<Meerkat::Collection>.
+#
+# =cut
 
 has collection_namespace => (
     is  => 'ro',
@@ -65,6 +103,31 @@ sub _build__mongo_default_database { $_[0]->database_name }
 # Methods
 #--------------------------------------------------------------------------#
 
+# =method new
+#
+#     my $meerkat = Meerkat->new(
+#         model_namespace => "My::Model",
+#         database_name   => "test",
+#         client_options  => {
+#             host => "mongodb://example.net:27017",
+#             username => "willywonka",
+#             password => "ilovechocolate",
+#         },
+#     );
+#
+# Generates and returns a new Meerkat object.  The C<model_namespace> and
+# C<database_name> attributes are required.
+#
+# =method collection
+#
+#     my $person = $meerkat->collection("Person"); # My::Model::Person
+#
+# Returns a L<Meerkat::Collection> factory object or possibly a subclass if a
+# C<collection_namespace> attribute has been provided. A single parameter is
+# required and is used as the suffix of a class name provided to the
+# Meerkat::Collection C<class> attribute.
+#
+# =cut
 
 sub collection {
     state $check = compile( Object, Str );
@@ -81,6 +144,19 @@ sub collection {
     return $class->new( class => $model, meerkat => $self );
 }
 
+# =method mongo_collection
+#
+#     my $coll = $meerkat->mongo_collection("My_Model_Person");
+#
+# Returns a raw L<MongoDB::Collection> object from the associated database.
+# This is used internally by L<Meerkat::Collection> and is not intended for
+# general use.
+#
+# =cut
+
+# alias _mongo_collection provided by MooseX::Role::MongoDB
+*mongo_collection = *_mongo_collection;
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -100,7 +176,7 @@ Meerkat - Manage MongoDB documents as Moose objects
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -271,6 +347,14 @@ C<collection_namespace> attribute has been provided. A single parameter is
 required and is used as the suffix of a class name provided to the
 Meerkat::Collection C<class> attribute.
 
+=head2 mongo_collection
+
+    my $coll = $meerkat->mongo_collection("My_Model_Person");
+
+Returns a raw L<MongoDB::Collection> object from the associated database.
+This is used internally by L<Meerkat::Collection> and is not intended for
+general use.
+
 =for Pod::Coverage BUILD
 
 =head1 EXCEPTION HANDLING
